@@ -102,6 +102,9 @@ class SegmentMappingSim(MetadynamicSimulation):
         if self.scan_bias < self.prod_bias:
             print('WARNING: scan bias should be high (40-50) and prod bias should be low (5-10)')
 
+        if self.fes_interval != self.traj_interval:
+            print('WARNING: traj interval and fes interval are different, CV indices will not match trajectory frames')
+
     def run_scans(self):
 
             self._remove_custom_forces()
@@ -330,10 +333,11 @@ class SegmentMappingSim(MetadynamicSimulation):
 
 class SegmentMappingSimHREMD(SegmentMappingSim):
 
-    def __init__(self, max_production_time=200 * unit.nanosecond, swap_freq = 2 * unit.nanosecond,
+    def __init__(self, max_production_time=200 * unit.nanosecond, min_production_time = 5 * unit.nanosecond,
+                 swap_freq = 2 * unit.nanosecond,
                  convergence_window=2 * unit.nanosecond, dG_displacement_criteria = 1, min_coverage_criteria=.25,
                  **kwargs):
-
+        self.min_production_time = min_production_time
         self.max_production_time = max_production_time
         self.swap_freq = swap_freq
         self.convergence_window = convergence_window
@@ -363,12 +367,12 @@ class SegmentMappingSimHREMD(SegmentMappingSim):
         self.simulation.minimizeEnergy()
 
         #get total num steps for reporters
-        nsteps = int(round(self.time_per_iteration / self.step_length)) * self.max_iterations
+        nsteps = int(self.max_production_time / self.step_length)
         print('nsteps for production phase',nsteps)
         self.simulation.reporters = []
         self._add_reporters(total_steps = nsteps + self.simulation.currentStep)
         #once again we fix the FES Reporter freq to ensure convergence detection works
-        self._add_FESReporter(fes_interval=.01 * unit.nanosecond)
+        self._add_FESReporter()
 
         self.cycle_replicas(self.segment_coords)
 
@@ -412,11 +416,9 @@ class SegmentMappingSimHREMD(SegmentMappingSim):
             if log_p_accept<=0 * unit.kilojoules_per_mole \
                     or random.random() < np.exp(-(log_p_accept/2.494341741366065).value_in_unit(unit.kilojoule_per_mole)) \
                     or current_cv1_distance>self.unbound_distance:
-                print('successfully swapped coordinates')
                 accepted +=1
                 attempted +=1
             else:
-                print('failed swap attempt')
                 attempted+=1
                 self.simulation.context.setPositions(current_positions)
             print('HREMD acceptance rate {}'.format(accepted/attempted))
@@ -429,21 +431,24 @@ class SegmentMappingSimHREMD(SegmentMappingSim):
 
             #get the rolling average dG displacement and variance of the production dG value trace over a limited range
             # dG_trace is written every .01 * ns / step_length steps
-            window_steps = int(int(self.convergence_window / self.step_length)/int(.01 * unit.nanosecond/self.step_length))
+            window_steps = int(int(self.convergence_window / self.step_length)/int(self.fes_interval/self.step_length))
             # print('window steps, len(dG-trace)',window_steps,len(dG_trace))
+
             if len(dG_trace)>window_steps:
-                dG_std = np.std(dG_trace[:-window_steps])
+                window_trace = dG_trace[:-window_steps]
+                dG_std = np.std(window_trace)
                 print('dG_std over the last {}: {}'.format(self.convergence_window,dG_std))
-                m_ave = moving_average(dG_trace[:-window_steps], np.max([1,int(len(dG_trace[:-window_steps])/10)]))
+                m_ave = moving_average(window_trace, np.max([1,int(len(window_trace)/3)]))
                 dG_displacement = np.max(m_ave) - np.min(m_ave)
                 print('dG_displacement over the last {}: {}'.format(self.convergence_window,dG_displacement))
 
             #convergence detected when there is significant coverage and dG std and dG rolling average displacement is low
             if coverage > self.min_coverage_criteria and \
+                sim_time > self.min_production_time and \
                 dG_std < self.convergence_criteria and \
                 dG_displacement < self.dG_displacement_criteria:
-                print('convergence detected! Coverage: '
-                      '{}, dG_std: {}, dG_displacement: {}'.format(coverage,dG_std,dG_displacement))
+                print("""convergence detected! Final dG {}:, coverage 
+                      {}, dG_std: {}, dG_displacement: {}""".format(dG_trace[-1],coverage,dG_std,dG_displacement))
                 continue_simulating= False
 
             #or complete when max time is hit
