@@ -504,3 +504,7 @@ def calc_dG(fes,order,cutoff=.75):
     else:
             dG = np.mean(dG_list)
     return dG
+
+
+def moving_average(x, w):
+    return np.convolve(x, np.ones(w), 'valid') / w
\ No newline at end of file
